/***************************************************************************
 *   Copyright (C) 2008 by Gustavo Pichorim Boiko                          *
 *   boiko@mandriva.com                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef IMAGEWIDGET_H
#define IMAGEWIDGET_H
#include <QWidget>

class ImageWidget : public QWidget
{
    Q_OBJECT
public:
    ImageWidget(QWidget *parent);
    ~ImageWidget();
   void setImage(const QImage &img);

public slots:
   void slotFileOpen();
   void slotFileSave();
   
   void slotApplyEffect();
   void slotReset();
   void slotCurrentChanged(int value);

   bool isRendered();
   void moveSelection(const QPoint &center);
   QPoint toWidget(const QPoint &p);
   QRect  toWidget(const QRect &r);
   QPoint fromWidget(const QPoint &p);

signals:
   void maxChanged(int value);
   void currentChanged(int value);
   void enableDisable();

protected:
    virtual void paintEvent(QPaintEvent *e);
    virtual void resizeEvent(QResizeEvent *e); 

    /* drag & drop */
    virtual void dragMoveEvent(QDragMoveEvent *e);
    virtual void dragEnterEvent(QDragEnterEvent *e);
    virtual void dropEvent(QDropEvent *e);

    /* mouse stuff */
    virtual void mouseMoveEvent(QMouseEvent *e);
    virtual void mousePressEvent(QMouseEvent *e);
    virtual void mouseReleaseEvent(QMouseEvent *e);

   void checkSelectionBounds();
private:
    QImage m_image;
    QImage m_currentImage;
    QPixmap m_scaledPixmap;
    QPixmap m_backgroundCache;
    QRect m_selectionRect;
    QSize m_baseSize;
    QRect m_imageRect;

    bool m_rendered;
    QSize m_selectionSize;
    float m_scale;
    bool m_pressed;
    QString m_lastPath;
};

#endif
