/***************************************************************************
 *   Copyright (C) 2008 by Gustavo Pichorim Boiko                          *
 *   boiko@mandriva.com                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "mywindow.h"
#include "imagewidget.h"

MyWindow::MyWindow()
{
    m_ui.setupUi(this);

    QHBoxLayout *l = new QHBoxLayout(m_ui.imageFrame);
    m_widget = new ImageWidget(m_ui.imageFrame);
    l->addWidget(m_widget);
    l->setMargin(0);
    l->setSpacing(0);

   // set values
   m_ui.sizeSlider->setMinimum(1200);
   m_ui.sizeSlider->setMaximum(2000);

   // connect signal/slots
   connect(m_ui.sizeSlider, SIGNAL(valueChanged(int)),
           m_widget, SLOT(slotCurrentChanged(int)));

   connect(m_ui.actionOpen, SIGNAL(triggered(bool)),
           m_widget, SLOT(slotFileOpen()));

   connect(m_ui.actionSave, SIGNAL(triggered(bool)),
           m_widget, SLOT(slotFileSave()));

   connect(m_ui.actionQuit, SIGNAL(triggered(bool)),
           this, SLOT(close()));

   connect(m_widget, SIGNAL(currentChanged(int)),
           m_ui.sizeSlider, SLOT(setValue(int)));

   connect(m_ui.applyButton, SIGNAL(clicked(bool)),
           m_widget, SLOT(slotApplyEffect()));
   connect(m_ui.resetButton, SIGNAL(clicked(bool)),
           m_widget, SLOT(slotReset()));
   connect(m_widget, SIGNAL(maxChanged(int)),
           this, SLOT(slotMaxChanged(int)));

   connect(m_widget, SIGNAL(enableDisable()),
           this, SLOT(slotEnableDisable()));

   slotEnableDisable();
}

MyWindow::~MyWindow()
{
}

void MyWindow::slotMaxChanged(int value)
{
    m_ui.sizeSlider->setMaximum(value);
}

void MyWindow::slotEnableDisable()
{
    bool rendered = m_widget->isRendered();

    m_ui.sizeSlider->setEnabled(!rendered);
    m_ui.applyButton->setEnabled(!rendered);

    m_ui.actionSave->setEnabled(rendered);
}
